@@ -16,9 +16,11 @@ macro_rules! __impl_slice_eq {
 __impl_slice_eq! { [] Vec<T>, Vec<U> }
 __impl_slice_eq! { [] Vec<T>, &[U] }
 __impl_slice_eq! { [] Vec<T>, &mut [U] }
+__impl_slice_eq! { [] Vec<T>, std::vec::Vec<U> }
 __impl_slice_eq! { [] &[T], Vec<U> }
 __impl_slice_eq! { [] &mut [T], Vec<U> }
 __impl_slice_eq! { [] Vec<T>, [U] }
 __impl_slice_eq! { [] [T], Vec<U> }
+__impl_slice_eq! { [] std::vec::Vec<T>, Vec<U> }
 __impl_slice_eq! { [const N: usize] Vec<T>, [U; N] }
 __impl_slice_eq! { [const N: usize] Vec<T>, &[U; N] }
